@@ -1329,8 +1329,8 @@ BodyPane :: create_followup ()
     else
     {
       // get the entire body...
-      gtk_text_buffer_get_bounds (_buffer, &start, &end);
-      pch = gtk_text_buffer_get_text (_buffer, &start, &end, false);
+      gboolean unused (false);
+      pch = g_mime_message_get_body (_message, true, &unused);
 
       // remove the sig...
       int sig_index (0);
