@@ -124,8 +124,7 @@ void GUI :: show_task_window_cb (GtkWidget * w, gpointer gui_gpointer)
 
 namespace
 {
-  std::string get_accel_filename ()
-  {
+  std::string get_accel_filename () {
     char * tmp = g_build_filename (file::get_pan_home().c_str(), "accels.txt", NULL);
     std::string ret (tmp);
     g_free (tmp);
@@ -134,7 +133,6 @@ namespace
 }
 
 
-
 GUI :: GUI (Data& data, Queue& queue, ArticleCache& cache, Prefs& prefs, GroupPrefs& group_prefs):
   _data (data),
   _queue (queue),
@@ -558,10 +556,25 @@ void GUI :: do_import_tasks ()
     _queue.add_tasks (tasks);
 }
 
+namespace
+{
+  void task_pane_destroyed_cb (GtkWidget * w, gpointer p)
+  {
+    TaskPane ** task_pane (static_cast<TaskPane**>(p));
+    *task_pane = 0;
+  }
+}
+
 void GUI :: do_show_task_window ()
 {
-  TaskPane * task_pane = new TaskPane (_queue, _prefs, _root);
-  gtk_widget_show (task_pane->root());
+  static TaskPane * task_pane (0);
+  if (task_pane)
+    gtk_window_present (GTK_WINDOW(task_pane->root()));
+  else {
+    task_pane = new TaskPane (_queue, _prefs);
+    g_signal_connect (task_pane->root(), "destroy", G_CALLBACK(task_pane_destroyed_cb), &task_pane);
+    gtk_widget_show (task_pane->root());
+  }
 }
 
 namespace
@@ -587,7 +600,7 @@ void GUI :: on_log_entry_added (const Log::Entry& e)
     std::string msg (e.message);
     if (msg.find ("ENOSPC") != e.message.npos) {
       msg.erase (msg.find ("ENOSPC"), 6);
-      msg += "\n \n";
+      msg += ' ';
       msg += _("Pan is now offline. Please ensure that space is available, then use File|Work Online to continue.");
       toggle_action ("work-online", false);
     }
@@ -603,7 +616,12 @@ void GUI :: on_log_entry_added (const Log::Entry& e)
 
 void GUI :: do_show_log_window ()
 {
-  gtk_widget_show (log_dialog_new (_prefs, get_window (_root)));
+  static GtkWidget * log_window (0);
+  if (!log_window) {
+    log_window = log_dialog_new (_prefs, get_window (_root));
+    g_signal_connect (log_window, "destroy", G_CALLBACK(gtk_widget_destroyed), &log_window);
+  }
+  gtk_window_present (GTK_WINDOW(log_window));
   set_bin_child (_event_log_button, _info_image);
 }
 void GUI :: do_select_all_articles ()
@@ -718,7 +736,11 @@ void GUI :: do_clear_body_pane ()
 void GUI :: do_read_more ()
 {
   if (!_body_pane->read_more ())
-    activate_action ("read-next-article");
+  {
+    activate_action (_prefs.get_flag ("space-selects-next-article", true)
+                     ? "read-next-article"
+                     : "read-next-unread-article");
+  }
 }
 void GUI :: do_read_less ()
 {
@@ -972,6 +994,7 @@ void GUI :: do_about_pan ()
 void GUI :: do_work_online (bool b)
 {
   _queue.set_online (b);
+  refresh_connection_label ();
 }
 
 namespace
@@ -1380,10 +1403,21 @@ GUI :: on_queue_size_changed (Queue& q, int active, int total)
   set_queue_size_label (active, total);
 }
 void
-GUI :: on_queue_online_changed (Queue& q, bool online)
+GUI :: on_queue_online_changed (Queue& q, bool is_online)
 {
-  refresh_connection_label ();
+  toggle_action ("work-online", is_online);
 }
+void
+GUI :: on_queue_error (Queue& q, const std::string& message)
+{
+  toggle_action ("work-online", false);
+
+  std::string s (message);
+  s += "\n \n";
+  s += _("Pan is now offline. Please see \"File|Event Log\" and correct the problem, then use \"File|Work Online\" to continue.");
+  Log::add_urgent_va ("%s", s.c_str());
+}
+
 
 void
 GUI :: on_prefs_flag_changed (const StringView& key, bool value)
