@@ -1445,7 +1445,10 @@ HeaderPane :: build_tree_columns ()
 
     if (name == "state")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_PIXBUF, "ypad", 0, "xpad", xpad, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_PIXBUF,
+        "xpad", xpad,
+        "ypad", 0,
+        NULL));
       col = gtk_tree_view_column_new ();
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 24));
@@ -1457,7 +1460,10 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "action")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_PIXBUF, "ypad", 0, "xpad", xpad, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_PIXBUF,
+        "xpad", xpad,
+        "ypad", 0,
+        NULL));
       col = gtk_tree_view_column_new ();
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 24));
@@ -1468,7 +1474,13 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "subject")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+        "ypad", 0,
+        "xpad", xpad,
+#       if GTK_CHECK_VERSION(2,6,0)
+        "ellipsize", PANGO_ELLIPSIZE_END,
+#       endif
+        NULL));
       col = gtk_tree_view_column_new_with_attributes (_("Subject"), r, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 400));
@@ -1480,7 +1492,14 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "score")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, "xalign", 1.0, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+        "ypad", 0,
+        "xpad", xpad,
+        "xalign", 1.0,
+#       if GTK_CHECK_VERSION(2,6,0)
+        "ellipsize", PANGO_ELLIPSIZE_END,
+#       endif
+        NULL));
       col = gtk_tree_view_column_new_with_attributes (_("Score"), r, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 50));
@@ -1491,8 +1510,13 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "author")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, NULL));
-      //col = gtk_tree_view_column_new_with_attributes (_("Author"), r, NULL);
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+        "xpad", xpad,
+        "ypad", 0,
+#       if GTK_CHECK_VERSION(2,6,0)
+        "ellipsize", PANGO_ELLIPSIZE_END,
+#       endif
+        NULL));
       col = gtk_tree_view_column_new_with_attributes (_("Author"), r, "text", COL_SHORT_AUTHOR, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 133));
@@ -1502,7 +1526,14 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "lines")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, "xalign", 1.0, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+        "xpad", xpad,
+        "ypad", 0,
+        "xalign", 1.0,
+#       if GTK_CHECK_VERSION(2,6,0)
+        "ellipsize", PANGO_ELLIPSIZE_END,
+#       endif
+        NULL));
       col = gtk_tree_view_column_new_with_attributes (_("Lines"), r, "text", COL_LINES, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 60));
@@ -1512,7 +1543,14 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "bytes")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, "xalign", 1.0, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+        "xpad", xpad,
+        "ypad", 0,
+        "xalign", 1.0,
+#       if GTK_CHECK_VERSION(2,6,0)
+        "ellipsize", PANGO_ELLIPSIZE_END,
+#       endif
+        NULL));
       col = gtk_tree_view_column_new_with_attributes (_("Bytes"), r, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 80));
@@ -1523,7 +1561,13 @@ HeaderPane :: build_tree_columns ()
     }
     else if (name == "date")
     {
-      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT, "ypad", 0, "xpad", xpad, NULL));
+      GtkCellRenderer * r = GTK_CELL_RENDERER (g_object_new (GTK_TYPE_CELL_RENDERER_TEXT,
+        "xpad", xpad,
+        "ypad", 0,
+#       if GTK_CHECK_VERSION(2,6,0)
+        "ellipsize", PANGO_ELLIPSIZE_END,
+#       endif
+        NULL));
       col = gtk_tree_view_column_new_with_attributes (_("Date"), r, "text", COL_DATE_STR, NULL);
       gtk_tree_view_column_set_sizing (col, GTK_TREE_VIEW_COLUMN_FIXED);
       gtk_tree_view_column_set_fixed_width (col, _prefs.get_int (width_key, 120));
