@@ -44,7 +44,6 @@ namespace
 {
   gboolean delete_event_cb (GtkWidget *w, GdkEvent *e, gpointer user_data)
   {
-std::cerr << LINE_ID << " calling gtk_main_quit..." << std::endl;
     gtk_main_quit ();
     return true; // don't invoke the default handler that destroys the widget
   }
@@ -142,7 +141,7 @@ main (int argc, char *argv[])
   textdomain (GETTEXT_PACKAGE);
 
   gtk_init (&argc, &argv);
-  g_mime_init (0);
+  g_mime_init (GMIME_INIT_FLAG_UTF8);
 
   bool gui(true), nzb(false);
   std::string url;
@@ -221,7 +220,7 @@ main (int argc, char *argv[])
       // don't open the full-blown Pan, just act as a nzb client,
       // with a gui or without.
       if (gui) {
-        TaskPane * pane = new TaskPane (queue, prefs, NULL);
+        TaskPane * pane = new TaskPane (queue, prefs);
         GtkWidget * w (pane->root());
         gtk_widget_show_all (w);
         g_signal_connect (w, "destroy", G_CALLBACK(destroy_cb), 0);
