@@ -704,8 +704,12 @@ PostUI :: on_progress_finished (Progress&, int status)
   _post_task->remove_listener (this);
   gtk_widget_destroy (_post_dialog);
   if (status == OK)
+  {
+    _unchanged_body = get_text (_body_buf);
     close_window ();
-  else {
+  }
+  else
+  {
     //if (status == FAIL)
     std::cerr << LINE_ID << " status " << status << std::endl;
   }
@@ -1027,13 +1031,18 @@ namespace
     return s;
   }
 
+  bool header_has_dedicated_entry (const StringView& name)
+  {
+    return (name == "Subject")
+        || (name == "Newsgroups")
+        || (name == "From");
+  }
+
   bool extra_header_is_editable (const StringView& name,
                                  const StringView& value)
   {
     const bool keep = !name.empty() // make sure header exists
-        && (name != "Subject") // not an extra header
-        && (name != "Newsgroups")
-        && (name != "From")
+        && (!header_has_dedicated_entry (name)) // not an extra header
         && (name != "Xref") // not editable
         && (name != "Message-ID")
         && (name != "References")
@@ -1140,6 +1149,7 @@ PostUI :: save_draft ()
     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
     GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
     NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG(d), GTK_RESPONSE_ACCEPT);
 
   if (!gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(d), draft_filename.c_str()))
     gtk_file_chooser_set_filename (GTK_FILE_CHOOSER(d), draft_filename.c_str());
@@ -1429,13 +1439,21 @@ PostUI :: apply_profile_to_body ()
 
   // replace the attribution
   const std::string old_attribution (_hidden_headers["X-Draft-Attribution"]);
-  if (!attribution.empty()) {
+  if (!attribution.empty())
+  {
+    // scrub the attribution for UTF8 cleanness
+    char * pch = content_to_utf8 (attribution.c_str(), attribution.size(), 0, 0);
+    if (pch)
+      attribution = pch;
+    else
+      attribution.clear ();
+    g_free (pch);
+ 
     std::string::size_type pos = body.find (old_attribution);
     if (!old_attribution.empty() && (pos != std::string::npos))
       body.replace (pos, old_attribution.size(), attribution);
-    else if (!attribution.empty()) {
+    else if (!attribution.empty())
       body = attribution + "\n\n" + body;
-    }
     _hidden_headers["X-Draft-Attribution"] = attribution;
   }
 
@@ -1541,12 +1559,22 @@ namespace
   void set_message_foreach_header_func (const char * name, const char * value, gpointer data_gpointer)
   {
     struct SetMessageForeachHeaderData * data (static_cast<SetMessageForeachHeaderData*>(data_gpointer));
-    if (!extra_header_is_editable (name, value))
-      data->hidden_headers[name] = value;
-    else {
+
+    if (header_has_dedicated_entry (name))
+    {
+      // it's not an extra header
+    }
+    else if (extra_header_is_editable (name, value))
+    {
+      // it's a visible extra header.
       std::string& str (data->visible_headers);
       str += std::string(name) + ": " + value + "\n";
     }
+    else
+    {
+      // it's a hidden extra header -- X-Draft-* headers, etc.
+      data->hidden_headers[name] = value;
+    }
   }
 }
 
