@@ -310,7 +310,7 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     w = new_check_button (_("Single-click activates, rather than selects, _articles"), "single-click-activates-article", true, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
   HIG::workarea_add_section_divider (t, &row);
-  HIG::workarea_add_section_title (t, &row, _("Group Management"));
+  HIG::workarea_add_section_title (t, &row, _("Groups"));
     HIG::workarea_add_section_spacer (t, row, 3);
     w = new_check_button (_("Get new headers in subscribed groups on _startup"), "get-new-headers-on-startup", false, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
@@ -318,6 +318,10 @@ PrefsDialog :: PrefsDialog (Prefs& prefs, GtkWindow* parent):
     HIG :: workarea_add_wide_control (t, &row, w);
     w = new_check_button (_("Mark entire group _read when leaving group"), "mark-group-read-when-leaving-group", false, prefs);
     HIG :: workarea_add_wide_control (t, &row, w);
+    HIG :: workarea_add_section_spacer (t, row, 1);
+    HIG :: workarea_add_section_title (t, &row, _("Articles"));
+    w = new_check_button (_("Space selects next article, not next unread"), "space-selects-next-article", true, prefs);
+    HIG :: workarea_add_wide_control (t, &row, w);
   HIG :: workarea_finish (t, &row);
   gtk_notebook_append_page (GTK_NOTEBOOK(notebook), t, gtk_label_new_with_mnemonic(_("_Behavior")));
 
