@@ -404,7 +404,7 @@ namespace {
   }
 }
 
-TaskPane :: TaskPane (Queue& queue, Prefs& prefs, GtkWidget* parent): _queue(queue)
+TaskPane :: TaskPane (Queue& queue, Prefs& prefs): _queue(queue)
 {
   _root = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
@@ -505,8 +505,6 @@ TaskPane :: TaskPane (Queue& queue, Prefs& prefs, GtkWidget* parent): _queue(que
   gtk_widget_show_all (vbox);
   prefs.set_window ("tasks-window", GTK_WINDOW(_root), 200, 200, 550, 600);
   gtk_window_set_resizable (GTK_WINDOW(_root), true);
-  if (parent != 0)
-    gtk_window_set_transient_for (GTK_WINDOW(_root), GTK_WINDOW(gtk_widget_get_toplevel(parent)));
 
   clear_pointer_on_destroy_signal (_root);
   clear_pointer_on_destroy_signal (_view);
