@@ -19,6 +19,7 @@
 
 #include <config.h>
 #include <ctime>
+#include <glib/gi18n.h>
 #include <pan/general/debug.h>
 #include <pan/general/foreach.h>
 #include "nntp-pool.h"
@@ -31,7 +32,6 @@ NNTP_Pool :: NNTP_Pool (const Quark        & server,
   _server_info (server_info),
   _server (server),
   _socket_creator (creator),
-  _is_online (true),
   _connection_pending (false)
 {
 }
@@ -49,23 +49,11 @@ NNTP_Pool :: ~NNTP_Pool ()
 ***/
 
 void
-NNTP_Pool :: set_online (bool b)
+NNTP_Pool :: abort_tasks ()
 {
-  if (b != _is_online)
-  {
-    _is_online = b;
-
-    if (!_is_online)
-      foreach (pool_items_t, _pool_items, it)
-        if (!it->is_checked_in)
-          it->nntp->_socket->set_abort_flag (true);
-  }
-}
-
-bool
-NNTP_Pool :: is_online () const
-{
-  return _is_online;
+  foreach (pool_items_t, _pool_items, it)
+    if (!it->is_checked_in)
+      it->nntp->_socket->set_abort_flag (true);
 }
 
 NNTP*
@@ -101,7 +89,7 @@ NNTP_Pool :: check_in (NNTP * nntp, bool is_ok)
     if (is_ok) {
       it->is_checked_in = true;
       it->last_active_time = time (NULL);
-      fire_nntp_available ();
+      fire_pool_has_nntp_available ();
     } else {
       delete it->nntp->_socket;
       delete it->nntp;
@@ -119,8 +107,6 @@ NNTP_Pool :: on_nntp_done (NNTP* nntp, Health health)
 {
    debug ("NNTP_Pool: on_nntp_done()");
 
-   const Quark& server (nntp->_server);
-
    if (health != OK)
    {
       delete nntp->_socket;
@@ -129,14 +115,19 @@ NNTP_Pool :: on_nntp_done (NNTP* nntp, Health health)
    }
 
    if (health == FAIL) // news server isn't accepting our connection!
-      set_online (false);
+   {
+     const std::string addr (_server_info.get_server_address (_server));
+     char buf[512];
+     std::snprintf (buf, sizeof(buf), _("Unable to connect to \"%s\""), addr.c_str());
+     fire_pool_error (buf);
+   }
 
    _connection_pending = false;
 
    // if success...
    if (nntp != 0)
    {
-      debug ("success with handshake to " << server << ", nntp " << nntp);
+      debug ("success with handshake to " << _server << ", nntp " << nntp);
 
       PoolItem i;
       i.nntp = nntp;
@@ -144,17 +135,10 @@ NNTP_Pool :: on_nntp_done (NNTP* nntp, Health health)
       i.last_active_time = time (0);
       _pool_items.push_back (i);
 
-      fire_nntp_available ();
+      fire_pool_has_nntp_available ();
    }
 }
 
-void
-NNTP_Pool :: fire_nntp_available ()
-{
-  for (listeners_t::iterator it(_listeners.begin()), end(_listeners.end()); it!=end; )
-    (*it++)->on_nntp_available (_server);
-}
-
 void
 NNTP_Pool :: get_counts (int& setme_active,
                          int& setme_idle,
@@ -184,17 +168,14 @@ NNTP_Pool :: request_nntp ()
    get_counts (active, idle, pending, max);
 
 #if 0
-std::cerr << LINE_ID << "server " << _server << ", is_online(): " << is_online() << ' '
+std::cerr << LINE_ID << "server " << _server << ", "
           << "active: " << active << ' '
           << "idle: " << idle << ' '
           << "pending: " << pending << ' '
           << "max: " << max << ' ' << std::endl;
 #endif
 
-   if (is_online()
-       && !idle
-       && !pending
-       && active<max)
+   if (!idle && !pending && active<max)
    {
       debug ("trying to create a socket");
 
