@@ -56,13 +56,19 @@ Queue :: ~Queue ()
 }
 
 void
-Queue :: on_nntp_available (const Quark& server)
+Queue :: on_pool_has_nntp_available (const Quark& server)
 {
   Task * task = find_first_task_needing_server (server);
   if (task != 0)
     process_task (task);
 }
 
+void
+Queue :: on_pool_error (const Quark& server, const std::string& message)
+{
+  fire_queue_error (message);
+}
+
 NNTP_Pool&
 Queue :: get_pool (const Quark& servername)
 {
@@ -239,7 +245,7 @@ Queue :: find_best_server (const quarks_t& servers, Quark& setme)
     const NNTP_Pool& pool (get_pool(server));
 
     int score (0);
-    if (_is_online && pool.is_online()) {
+    if (_is_online) {
       int active, idle, pending, max;
       pool.get_counts (active, idle, pending, max);
       const int empty_slots (max - (idle+active));
@@ -262,6 +268,12 @@ Queue :: find_best_server (const quarks_t& servers, Quark& setme)
 ****
 ***/
 
+void
+Queue :: fire_queue_error (const std::string& message)
+{
+  for (lit it(_listeners.begin()), end(_listeners.end()); it!=end; )
+    (*it++)->on_queue_error (*this, message);
+}
 void
 Queue :: fire_tasks_added (int index, int count)
 {
