@@ -97,7 +97,7 @@ TaskArticle :: TaskArticle (const ServerRank          & server_rank,
   foreach_const (Article::parts_t, article.parts, it)
   {
     all_bytes += it->bytes;
-    if (!cache.contains (it->message_id))
+    if (!it->empty() && !cache.contains (it->message_id))
     {
       need_bytes += it->bytes;
 
